package Locale::CLDR::Locales::Lrc::Any;

# This file auto generated
#	on Sat  6 Feb 10:51:19 am GMT

use version;

our $VERSION = version->declare('v0.28.3');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

extends('Locale::CLDR::Locales::Lrc');

no Moose;
__PACKAGE__->meta->make_immutable;
